@@ -4,11 +4,17 @@ Utility to redact sensitive data
 """
 
 import argparse
-from ast import arg
+
 from pyredactkit.redact import Redactor
 from pyredactkit.unredact import Unredactor
 import os
 import glob
+import sys
+
+# Creating instances of redact and unredact classes
+redact_obj = Redactor()
+unredact_obj = Unredactor()
+
 
 banner = """
     ______       ______         _            _     _   ___ _   
@@ -27,48 +33,66 @@ banner = """
     https://brootware.github.io                                                                             
     """
 
+help_menu = """
+    PyRedactKit - Redact and Un-redact any sensitive data from your text files!
 
-def main():
-    print(banner)
+    Github:\n
+    https://github.com/brootware/pyredactkit
+    
+    Follow me on Twitter!\n
+    https://twitter.com/brootware
+    
+    Example usage:\n
+        pyredactkit --text 'This is my ip: 127.0.0.1. My email is brute@gmail.com'\n
+        pyredactkit --file [file/filestoredact]\n
+        pyredactkit --file redacted_file --unredact .hashshadow.json\n
+        pyredactkit --file file --customfile custom.json\n
+    """
 
+
+def arg_helper() -> argparse.Namespace:
     parser = argparse.ArgumentParser(
-        description='Read in a file or set of files, and return the result.',
+        description="Supply a sentence or paragraph to redact sensitive data from it. Or read in a file or set of files with -f to redact",
         formatter_class=argparse.ArgumentDefaultsHelpFormatter
     )
     parser.add_argument(
-        "file",
+        "text",
+        type=str,
+        help="""Redact sensitive data of a sentence from command prompt.""",
+        nargs="*"
+    )
+    if len(sys.argv) == 1:
+        parser.print_help(sys.stderr)
+        sys.exit(1)
+    parser.add_argument(
+        "-f",
+        "--file",
         nargs="+",
-        help="""
-        Path of a file or a directory of files.
-        Usage: pyredactkit [file/filestoredact]"""
+        help="""Path of a file or a directory of files."""
     )
     parser.add_argument(
         "-u",
         "--unredact",
         help="""
-        Option to unredact masked data.
-        Usage: pyredactkit [redacted_file] -u [.hashshadow.json]
-        """
-    )
-    parser.add_argument(
-        "-t", "--redactiontype",
-        help="""Type of data to redact. 
-        names,
-        nric,
-        dns,
-        emails,
-        ipv4,
-        ipv6,
-        base64.
-        Usage: pyredactkit [file/filestoredact] -t ip"""
+                Option to unredact masked data.
+                Usage: pyredactkit -f [redacted_file] -u [.hashshadow.json]
+                """
     )
     parser.add_argument(
         "-d",
         "--dirout",
         help="""
-        Output directory of the file.
-        Usage: pyredactkit [file/filestoredact] -d [redacted_dir]
-        """
+                Output directory of the file.
+                Usage: pyredactkit -f [file/filestoredact] -d [redacted_dir]
+                """
+    )
+    parser.add_argument(
+        "-c",
+        "--customfile",
+        help="""
+                User defined custom regex pattern for redaction.
+                Usage: pyredactkit -f [file/filestoredact] -c [customfile.json]
+                """
     )
     parser.add_argument(
         '-r',
@@ -85,6 +109,11 @@ def main():
     )
     args = parser.parse_args()
 
+    return args
+
+
+def execute_file_arg() -> None:
+    args = arg_helper()
     full_paths = [os.path.join(os.getcwd(), path) for path in args.file]
     files = set()
 
@@ -96,22 +125,30 @@ def main():
         elif args.recursive:
             full_paths += glob.glob(path + '/*')
 
-    # redact file
-    redact_obj = Redactor()
-    unredact_obj = Unredactor()
-
     for file in files:
-        if args.redactiontype:
-            redact_obj.process_file(file, args.redactiontype)
+        if args.customfile:
+            redact_obj.process_custom_file(file, args.customfile)
+            redact_obj.process_report(file)
         elif args.dirout:
-            redact_obj.process_file(file, args.redactiontype, args.dirout)
+            redact_obj.process_core_file(file, args.dirout)
+            redact_obj.process_custom_file(file, args.custom, args.dirout)
             redact_obj.process_report(file, args.dirout)
         elif args.unredact:
             unredact_obj.unredact(file, args.unredact)
         else:
-            redact_obj.process_file(file)
+            redact_obj.process_core_file(file)
             redact_obj.process_report(file)
 
 
+def main():
+    print(banner)
+
+    args = arg_helper()
+    if args.file or (args.file and args.dirout):
+        execute_file_arg()
+    else:
+        redact_obj.process_text(args.text)
+
+
 if __name__ == "__main__":
     main()
